SystemOrganization addCategory: #'Seaside-Tests-UTF8'!

WAContextTest subclass: #WAUtf8ResponseTest
	instanceVariableNames: 'response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'lr 7/16/2009 08:50'!
asString: aCollectionOfIntegers
	^String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
assertLines: anArray
	self assert: self lines = anArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
contents
	| stream |
	stream := WriteStream on: String new.
	self response writeOn: stream.
	^ stream contents! !

!WAUtf8ResponseTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'jf 9/30/2009 01:06'!
lines
	"Answer the response as an array of lines, to be used within the tests."
	| result stream |
	result := OrderedCollection new.
	stream := self contents readStream.
	[ stream atEnd ] whileFalse: 
		[ result add: (stream greaseUpToAll: (String 
					with: Character cr
					with: Character lf)) ].
	^ result asArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
response
	^ response ifNil: [ response := WABufferedResponse new ]! !

!WAUtf8ResponseTest methodsFor: 'testing' stamp: 'pmm 7/5/2009 20:04'!
testRedirectTo
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self response redirectTo: url.
	self assertLines:  #('HTTP/1.1 302 Found'
		'Location: http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'
		'Content-Length: 0' '')! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:53'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

WAContextTest subclass: #WAUtf8UrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8UrlTest methodsFor: 'private' stamp: 'lr 7/16/2009 08:52'!
asString: aCollectionOfIntegers
	^String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8UrlTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8UrlTest methodsFor: 'testing' stamp: 'pmm 7/5/2009 20:06'!
testPrintString
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self assert: url printString = 'http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'! !

!WAUtf8UrlTest methodsFor: 'private' stamp: 'pmm 7/5/2009 20:05'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

TestCase subclass: #WAUtf8CodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8CodecTest methodsFor: 'private' stamp: 'lr 7/16/2009 08:53'!
asString: aCollectionOfIntegers
	^String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8CodecTest methodsFor: 'accessing' stamp: 'pmm 7/4/2009 23:36'!
latin1String
	^ self asString: #(220 98 232 114 115 116 114 238 241 103 233)! !

!WAUtf8CodecTest methodsFor: 'testing' stamp: 'jf 9/30/2009 00:27'!
testCodecUtf8
	| codec |
	codec := GRCodec forEncoding: 'utf-8'.
	self assert: codec name = 'utf-8'.
	self assert: codec url name = 'utf-8'.
	self assert: (codec encode: self latin1String) = self utf8String.
	self assert: (codec url encode: self latin1String) = self utf8String.
	self assert: (codec decode: self utf8String) = self latin1String.
	self assert: (codec url decode: self utf8String) = self latin1String! !

!WAUtf8CodecTest methodsFor: 'testing' stamp: 'jf 9/30/2009 00:27'!
testCodecUtf8Binary
	| codec binary encoder |
	codec := GRCodec forEncoding: 'utf-8'.
	binary := self utf8String asByteArray.
	encoder := codec encoderFor: (WriteStream on: String new).
	encoder binary.
	encoder nextPutAll: binary.
	self assert: encoder contents = binary asString! !

!WAUtf8CodecTest methodsFor: 'testing' stamp: 'jf 9/30/2009 00:27'!
testCodecUtf8Bom
	| codec bom |
	codec := GRCodec forEncoding: 'utf-8'.
	bom := self asString: #(239 187 191 ).
	self assert: (codec decode: bom , self utf8String) = self latin1String.
	self assert: (codec url decode: bom , self utf8String) = self latin1String! !

!WAUtf8CodecTest methodsFor: 'testing' stamp: 'jf 9/30/2009 00:27'!
testCodecUtf8ShortestForm
	"Non shortest form characters should be rejected
	See Corrigendum #1: UTF-8 Shortest Form http://www.unicode.org/versions/corrigendum1.html"
	| codec abc |
	codec := GRCodec forEncoding: 'utf-8'.
	abc := self asString: #(193 129 193 130 193 131 ).
	self assert: (codec decode: abc) ~= 'ABC'! !

!WAUtf8CodecTest methodsFor: 'accessing' stamp: 'pmm 7/4/2009 23:36'!
utf8String
	^ self asString: #(195 156 98 195 168 114 115 116 114 195 174 195 177 103 195 169)! !

!GRPackage class methodsFor: '*seaside-tests-utf8' stamp: 'pmm 7/4/2009 23:33'!
seasideTestsUtf8
	^ self new
		name: 'Seaside-Tests-UTF8';
		description: 'Unit tests for UTF8 support.';
		addDependency: 'Seaside-Tests-Core';
		yourself! !
